from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="JsonNodeOptions")


@_attrs_define
class JsonNodeOptions:
    """Options to control JsonNode behavior.

    Attributes:
        property_name_case_insensitive (Union[Unset, bool]): Gets or sets a value that indicates whether property names
            on JsonObject are case insensitive.
    """

    property_name_case_insensitive: Union[Unset, bool] = UNSET

    def to_dict(self) -> dict[str, Any]:
        property_name_case_insensitive = self.property_name_case_insensitive

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if property_name_case_insensitive is not UNSET:
            field_dict["propertyNameCaseInsensitive"] = property_name_case_insensitive

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        property_name_case_insensitive = d.pop("propertyNameCaseInsensitive", UNSET)

        json_node_options = cls(
            property_name_case_insensitive=property_name_case_insensitive,
        )

        return json_node_options



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="DocumentFileDto")


@_attrs_define
class DocumentFileDto:
    """
    Attributes:
        id (Union[Unset, int]):
        file_id (Union[Unset, str]):
        doc_file_id (Union[Unset, str]):
        name (Union[None, Unset, str]):
        content_type (Union[None, Unset, str]):
        file_extension (Union[None, Unset, str]):
        size (Union[Unset, int]):
        workspace_id (Union[None, Unset, str]):
    """

    id: Union[Unset, int] = UNSET
    file_id: Union[Unset, str] = UNSET
    doc_file_id: Union[Unset, str] = UNSET
    name: Union[None, Unset, str] = UNSET
    content_type: Union[None, Unset, str] = UNSET
    file_extension: Union[None, Unset, str] = UNSET
    size: Union[Unset, int] = UNSET
    workspace_id: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        file_id = self.file_id

        doc_file_id = self.doc_file_id

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        content_type: Union[None, Unset, str]
        if isinstance(self.content_type, Unset):
            content_type = UNSET
        else:
            content_type = self.content_type

        file_extension: Union[None, Unset, str]
        if isinstance(self.file_extension, Unset):
            file_extension = UNSET
        else:
            file_extension = self.file_extension

        size = self.size

        workspace_id: Union[None, Unset, str]
        if isinstance(self.workspace_id, Unset):
            workspace_id = UNSET
        else:
            workspace_id = self.workspace_id

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if file_id is not UNSET:
            field_dict["fileId"] = file_id
        if doc_file_id is not UNSET:
            field_dict["docFileId"] = doc_file_id
        if name is not UNSET:
            field_dict["name"] = name
        if content_type is not UNSET:
            field_dict["contentType"] = content_type
        if file_extension is not UNSET:
            field_dict["fileExtension"] = file_extension
        if size is not UNSET:
            field_dict["size"] = size
        if workspace_id is not UNSET:
            field_dict["workspaceId"] = workspace_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        file_id = d.pop("fileId", UNSET)

        doc_file_id = d.pop("docFileId", UNSET)

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_content_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        content_type = _parse_content_type(d.pop("contentType", UNSET))

        def _parse_file_extension(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        file_extension = _parse_file_extension(d.pop("fileExtension", UNSET))

        size = d.pop("size", UNSET)

        def _parse_workspace_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        workspace_id = _parse_workspace_id(d.pop("workspaceId", UNSET))

        document_file_dto = cls(
            id=id,
            file_id=file_id,
            doc_file_id=doc_file_id,
            name=name,
            content_type=content_type,
            file_extension=file_extension,
            size=size,
            workspace_id=workspace_id,
        )

        return document_file_dto



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="RecordRelationDto")


@_attrs_define
class RecordRelationDto:
    """
    Attributes:
        id (Union[Unset, str]):
        relationship (Union[Unset, str]):
        since (Union[None, Unset, datetime.datetime]):
    """

    id: Union[Unset, str] = UNSET
    relationship: Union[Unset, str] = UNSET
    since: Union[None, Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        relationship = self.relationship

        since: Union[None, Unset, str]
        if isinstance(self.since, Unset):
            since = UNSET
        elif isinstance(self.since, datetime.datetime):
            since = self.since.isoformat()
        else:
            since = self.since

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if relationship is not UNSET:
            field_dict["relationship"] = relationship
        if since is not UNSET:
            field_dict["since"] = since

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        relationship = d.pop("relationship", UNSET)

        def _parse_since(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                since_type_0 = isoparse(data)

                return since_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        since = _parse_since(d.pop("since", UNSET))

        record_relation_dto = cls(
            id=id,
            relationship=relationship,
            since=since,
        )

        return record_relation_dto



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.tool_dto import ToolDto
    from ..models.workspace_dto import WorkspaceDto


T = TypeVar("T", bound="MiniTemplateDto")


@_attrs_define
class MiniTemplateDto:
    """
    Attributes:
        id (Union[Unset, str]):
        name (Union[Unset, str]):
        description (Union[None, Unset, str]):
        instructions (Union[None, Unset, str]):
        workspaces (Union[Unset, list['WorkspaceDto']]):
        tools (Union[Unset, list['ToolDto']]):
    """

    id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    instructions: Union[None, Unset, str] = UNSET
    workspaces: Union[Unset, list["WorkspaceDto"]] = UNSET
    tools: Union[Unset, list["ToolDto"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        name = self.name

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        instructions: Union[None, Unset, str]
        if isinstance(self.instructions, Unset):
            instructions = UNSET
        else:
            instructions = self.instructions

        workspaces: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.workspaces, Unset):
            workspaces = []
            for workspaces_item_data in self.workspaces:
                workspaces_item = workspaces_item_data.to_dict()
                workspaces.append(workspaces_item)

        tools: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.tools, Unset):
            tools = []
            for tools_item_data in self.tools:
                tools_item = tools_item_data.to_dict()
                tools.append(tools_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if instructions is not UNSET:
            field_dict["instructions"] = instructions
        if workspaces is not UNSET:
            field_dict["workspaces"] = workspaces
        if tools is not UNSET:
            field_dict["tools"] = tools

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.tool_dto import ToolDto
        from ..models.workspace_dto import WorkspaceDto

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        name = d.pop("name", UNSET)

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_instructions(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        instructions = _parse_instructions(d.pop("instructions", UNSET))

        workspaces = []
        _workspaces = d.pop("workspaces", UNSET)
        for workspaces_item_data in _workspaces or []:
            workspaces_item = WorkspaceDto.from_dict(workspaces_item_data)

            workspaces.append(workspaces_item)

        tools = []
        _tools = d.pop("tools", UNSET)
        for tools_item_data in _tools or []:
            tools_item = ToolDto.from_dict(tools_item_data)

            tools.append(tools_item)

        mini_template_dto = cls(
            id=id,
            name=name,
            description=description,
            instructions=instructions,
            workspaces=workspaces,
            tools=tools,
        )

        return mini_template_dto



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from .. import types
from ..types import UNSET, Unset

T = TypeVar("T", bound="AddAttachmentsBody")


@_attrs_define
class AddAttachmentsBody:
    """
    Attributes:
        files (Union[None, Unset, list[Any]]):
    """

    files: Union[None, Unset, list[Any]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        files: Union[None, Unset, list[Any]]
        if isinstance(self.files, Unset):
            files = UNSET
        elif isinstance(self.files, list):
            files = self.files

        else:
            files = self.files

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if files is not UNSET:
            field_dict["files"] = files

        return field_dict

    def to_multipart(self) -> types.RequestFiles:
        files: types.RequestFiles = []

        if not isinstance(self.files, Unset):
            if isinstance(self.files, list):
                for files_type_0_item_element in self.files:
                    files.append(("files", (None, str(files_type_0_item_element).encode(), "text/plain")))
            else:
                files.append(("files", (None, str(self.files).encode(), "text/plain")))

        for prop_name, prop in self.additional_properties.items():
            files.append((prop_name, (None, str(prop).encode(), "text/plain")))

        return files

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_files(data: object) -> Union[None, Unset, list[Any]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                files_type_0 = cast(list[Any], data)

                return files_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[Any]], data)

        files = _parse_files(d.pop("files", UNSET))

        add_attachments_body = cls(
            files=files,
        )

        add_attachments_body.additional_properties = d
        return add_attachments_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.paginated_list_of_record_dto import PaginatedListOfRecordDto
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    body: list[str],
    mini_id: Union[None, Unset, str] = UNSET,
    session_id: Union[None, Unset, str] = UNSET,
    page_number: Union[Unset, int] = 1,
    page_size: Union[Unset, int] = 10,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    params: dict[str, Any] = {}

    json_mini_id: Union[None, Unset, str]
    if isinstance(mini_id, Unset):
        json_mini_id = UNSET
    else:
        json_mini_id = mini_id
    params["miniId"] = json_mini_id

    json_session_id: Union[None, Unset, str]
    if isinstance(session_id, Unset):
        json_session_id = UNSET
    else:
        json_session_id = session_id
    params["sessionId"] = json_session_id

    params["pageNumber"] = page_number

    params["pageSize"] = page_size

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api/Records/external",
        "params": params,
    }

    _kwargs["json"] = body

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[PaginatedListOfRecordDto]:
    if response.status_code == 200:
        response_200 = PaginatedListOfRecordDto.from_dict(response.json())

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[PaginatedListOfRecordDto]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: list[str],
    mini_id: Union[None, Unset, str] = UNSET,
    session_id: Union[None, Unset, str] = UNSET,
    page_number: Union[Unset, int] = 1,
    page_size: Union[Unset, int] = 10,
) -> Response[PaginatedListOfRecordDto]:
    """
    Args:
        mini_id (Union[None, Unset, str]):
        session_id (Union[None, Unset, str]):
        page_number (Union[Unset, int]):  Default: 1.
        page_size (Union[Unset, int]):  Default: 10.
        body (list[str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PaginatedListOfRecordDto]
    """

    kwargs = _get_kwargs(
        body=body,
        mini_id=mini_id,
        session_id=session_id,
        page_number=page_number,
        page_size=page_size,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: list[str],
    mini_id: Union[None, Unset, str] = UNSET,
    session_id: Union[None, Unset, str] = UNSET,
    page_number: Union[Unset, int] = 1,
    page_size: Union[Unset, int] = 10,
) -> Optional[PaginatedListOfRecordDto]:
    """
    Args:
        mini_id (Union[None, Unset, str]):
        session_id (Union[None, Unset, str]):
        page_number (Union[Unset, int]):  Default: 1.
        page_size (Union[Unset, int]):  Default: 10.
        body (list[str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PaginatedListOfRecordDto
    """

    return sync_detailed(
        client=client,
        body=body,
        mini_id=mini_id,
        session_id=session_id,
        page_number=page_number,
        page_size=page_size,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: list[str],
    mini_id: Union[None, Unset, str] = UNSET,
    session_id: Union[None, Unset, str] = UNSET,
    page_number: Union[Unset, int] = 1,
    page_size: Union[Unset, int] = 10,
) -> Response[PaginatedListOfRecordDto]:
    """
    Args:
        mini_id (Union[None, Unset, str]):
        session_id (Union[None, Unset, str]):
        page_number (Union[Unset, int]):  Default: 1.
        page_size (Union[Unset, int]):  Default: 10.
        body (list[str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PaginatedListOfRecordDto]
    """

    kwargs = _get_kwargs(
        body=body,
        mini_id=mini_id,
        session_id=session_id,
        page_number=page_number,
        page_size=page_size,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: list[str],
    mini_id: Union[None, Unset, str] = UNSET,
    session_id: Union[None, Unset, str] = UNSET,
    page_number: Union[Unset, int] = 1,
    page_size: Union[Unset, int] = 10,
) -> Optional[PaginatedListOfRecordDto]:
    """
    Args:
        mini_id (Union[None, Unset, str]):
        session_id (Union[None, Unset, str]):
        page_number (Union[Unset, int]):  Default: 1.
        page_size (Union[Unset, int]):  Default: 10.
        body (list[str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PaginatedListOfRecordDto
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
            mini_id=mini_id,
            session_id=session_id,
            page_number=page_number,
            page_size=page_size,
        )
    ).parsed



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.json_node_options import JsonNodeOptions


T = TypeVar("T", bound="JsonNode")


@_attrs_define
class JsonNode:
    """The base class that represents a single node within a mutable JSON document.

    Attributes:
        options (Union['JsonNodeOptions', None, Unset]): Gets the options to control the behavior.
        parent (Union['JsonNode', None, Unset]): Gets the parent JsonNode.
                          If there is no parent, null is returned.
                          A parent can either be a JsonObject or a JsonArray.
        root (Union[Unset, JsonNode]): The base class that represents a single node within a mutable JSON document.
    """

    options: Union["JsonNodeOptions", None, Unset] = UNSET
    parent: Union["JsonNode", None, Unset] = UNSET
    root: Union[Unset, "JsonNode"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.json_node_options import JsonNodeOptions

        options: Union[None, Unset, dict[str, Any]]
        if isinstance(self.options, Unset):
            options = UNSET
        elif isinstance(self.options, JsonNodeOptions):
            options = self.options.to_dict()
        else:
            options = self.options

        parent: Union[None, Unset, dict[str, Any]]
        if isinstance(self.parent, Unset):
            parent = UNSET
        elif isinstance(self.parent, JsonNode):
            parent = self.parent.to_dict()
        else:
            parent = self.parent

        root: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.root, Unset):
            root = self.root.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if options is not UNSET:
            field_dict["options"] = options
        if parent is not UNSET:
            field_dict["parent"] = parent
        if root is not UNSET:
            field_dict["root"] = root

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.json_node_options import JsonNodeOptions

        d = dict(src_dict)

        def _parse_options(data: object) -> Union["JsonNodeOptions", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                options_type_0 = JsonNodeOptions.from_dict(data)

                return options_type_0
            except:  # noqa: E722
                pass
            return cast(Union["JsonNodeOptions", None, Unset], data)

        options = _parse_options(d.pop("options", UNSET))

        def _parse_parent(data: object) -> Union["JsonNode", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                parent_type_0 = JsonNode.from_dict(data)

                return parent_type_0
            except:  # noqa: E722
                pass
            return cast(Union["JsonNode", None, Unset], data)

        parent = _parse_parent(d.pop("parent", UNSET))

        _root = d.pop("root", UNSET)
        root: Union[Unset, JsonNode]
        if isinstance(_root, Unset):
            root = UNSET
        else:
            root = JsonNode.from_dict(_root)

        json_node = cls(
            options=options,
            parent=parent,
            root=root,
        )

        return json_node



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="UpdateGroupCommand")


@_attrs_define
class UpdateGroupCommand:
    """
    Attributes:
        group_id (Union[Unset, str]):
        name (Union[None, Unset, str]):
        user_ids (Union[None, Unset, list[str]]):
        mini_ids (Union[None, Unset, list[int]]):
    """

    group_id: Union[Unset, str] = UNSET
    name: Union[None, Unset, str] = UNSET
    user_ids: Union[None, Unset, list[str]] = UNSET
    mini_ids: Union[None, Unset, list[int]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        group_id = self.group_id

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        user_ids: Union[None, Unset, list[str]]
        if isinstance(self.user_ids, Unset):
            user_ids = UNSET
        elif isinstance(self.user_ids, list):
            user_ids = self.user_ids

        else:
            user_ids = self.user_ids

        mini_ids: Union[None, Unset, list[int]]
        if isinstance(self.mini_ids, Unset):
            mini_ids = UNSET
        elif isinstance(self.mini_ids, list):
            mini_ids = self.mini_ids

        else:
            mini_ids = self.mini_ids

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if group_id is not UNSET:
            field_dict["groupId"] = group_id
        if name is not UNSET:
            field_dict["name"] = name
        if user_ids is not UNSET:
            field_dict["userIds"] = user_ids
        if mini_ids is not UNSET:
            field_dict["miniIds"] = mini_ids

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        group_id = d.pop("groupId", UNSET)

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_user_ids(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                user_ids_type_0 = cast(list[str], data)

                return user_ids_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        user_ids = _parse_user_ids(d.pop("userIds", UNSET))

        def _parse_mini_ids(data: object) -> Union[None, Unset, list[int]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                mini_ids_type_0 = cast(list[int], data)

                return mini_ids_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list[int]], data)

        mini_ids = _parse_mini_ids(d.pop("miniIds", UNSET))

        update_group_command = cls(
            group_id=group_id,
            name=name,
            user_ids=user_ids,
            mini_ids=mini_ids,
        )

        return update_group_command



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.create_record_command_tags import CreateRecordCommandTags
    from ..models.json_node import JsonNode
    from ..models.record_authorization_dto import RecordAuthorizationDto
    from ..models.record_relation_dto import RecordRelationDto


T = TypeVar("T", bound="CreateRecordCommand")


@_attrs_define
class CreateRecordCommand:
    """
    Attributes:
        title (Union[Unset, str]):
        description (Union[None, Unset, str]):
        mini_id (Union[None, Unset, str]):
        event_date (Union[None, Unset, datetime.datetime]):
        schema (Union['JsonNode', None, Unset]):
        content (Union['JsonNode', None, Unset]):
        relations (Union[Unset, list['RecordRelationDto']]):
        external_uri (Union[None, Unset, str]):
        labels (Union[Unset, list[str]]):
        tags (Union[Unset, CreateRecordCommandTags]):
        authorization (Union[Unset, RecordAuthorizationDto]):
    """

    title: Union[Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    mini_id: Union[None, Unset, str] = UNSET
    event_date: Union[None, Unset, datetime.datetime] = UNSET
    schema: Union["JsonNode", None, Unset] = UNSET
    content: Union["JsonNode", None, Unset] = UNSET
    relations: Union[Unset, list["RecordRelationDto"]] = UNSET
    external_uri: Union[None, Unset, str] = UNSET
    labels: Union[Unset, list[str]] = UNSET
    tags: Union[Unset, "CreateRecordCommandTags"] = UNSET
    authorization: Union[Unset, "RecordAuthorizationDto"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.json_node import JsonNode

        title = self.title

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        mini_id: Union[None, Unset, str]
        if isinstance(self.mini_id, Unset):
            mini_id = UNSET
        else:
            mini_id = self.mini_id

        event_date: Union[None, Unset, str]
        if isinstance(self.event_date, Unset):
            event_date = UNSET
        elif isinstance(self.event_date, datetime.datetime):
            event_date = self.event_date.isoformat()
        else:
            event_date = self.event_date

        schema: Union[None, Unset, dict[str, Any]]
        if isinstance(self.schema, Unset):
            schema = UNSET
        elif isinstance(self.schema, JsonNode):
            schema = self.schema.to_dict()
        else:
            schema = self.schema

        content: Union[None, Unset, dict[str, Any]]
        if isinstance(self.content, Unset):
            content = UNSET
        elif isinstance(self.content, JsonNode):
            content = self.content.to_dict()
        else:
            content = self.content

        relations: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.relations, Unset):
            relations = []
            for relations_item_data in self.relations:
                relations_item = relations_item_data.to_dict()
                relations.append(relations_item)

        external_uri: Union[None, Unset, str]
        if isinstance(self.external_uri, Unset):
            external_uri = UNSET
        else:
            external_uri = self.external_uri

        labels: Union[Unset, list[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        tags: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        authorization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.authorization, Unset):
            authorization = self.authorization.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description
        if mini_id is not UNSET:
            field_dict["miniId"] = mini_id
        if event_date is not UNSET:
            field_dict["eventDate"] = event_date
        if schema is not UNSET:
            field_dict["schema"] = schema
        if content is not UNSET:
            field_dict["content"] = content
        if relations is not UNSET:
            field_dict["relations"] = relations
        if external_uri is not UNSET:
            field_dict["externalUri"] = external_uri
        if labels is not UNSET:
            field_dict["labels"] = labels
        if tags is not UNSET:
            field_dict["tags"] = tags
        if authorization is not UNSET:
            field_dict["authorization"] = authorization

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_record_command_tags import CreateRecordCommandTags
        from ..models.json_node import JsonNode
        from ..models.record_authorization_dto import RecordAuthorizationDto
        from ..models.record_relation_dto import RecordRelationDto

        d = dict(src_dict)
        title = d.pop("title", UNSET)

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_mini_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        mini_id = _parse_mini_id(d.pop("miniId", UNSET))

        def _parse_event_date(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                event_date_type_0 = isoparse(data)

                return event_date_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        event_date = _parse_event_date(d.pop("eventDate", UNSET))

        def _parse_schema(data: object) -> Union["JsonNode", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                schema_type_0 = JsonNode.from_dict(data)

                return schema_type_0
            except:  # noqa: E722
                pass
            return cast(Union["JsonNode", None, Unset], data)

        schema = _parse_schema(d.pop("schema", UNSET))

        def _parse_content(data: object) -> Union["JsonNode", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                content_type_0 = JsonNode.from_dict(data)

                return content_type_0
            except:  # noqa: E722
                pass
            return cast(Union["JsonNode", None, Unset], data)

        content = _parse_content(d.pop("content", UNSET))

        relations = []
        _relations = d.pop("relations", UNSET)
        for relations_item_data in _relations or []:
            relations_item = RecordRelationDto.from_dict(relations_item_data)

            relations.append(relations_item)

        def _parse_external_uri(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_uri = _parse_external_uri(d.pop("externalUri", UNSET))

        labels = cast(list[str], d.pop("labels", UNSET))

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, CreateRecordCommandTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = CreateRecordCommandTags.from_dict(_tags)

        _authorization = d.pop("authorization", UNSET)
        authorization: Union[Unset, RecordAuthorizationDto]
        if isinstance(_authorization, Unset):
            authorization = UNSET
        else:
            authorization = RecordAuthorizationDto.from_dict(_authorization)

        create_record_command = cls(
            title=title,
            description=description,
            mini_id=mini_id,
            event_date=event_date,
            schema=schema,
            content=content,
            relations=relations,
            external_uri=external_uri,
            labels=labels,
            tags=tags,
            authorization=authorization,
        )

        return create_record_command



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserToMiniDto")


@_attrs_define
class UserToMiniDto:
    """
    Attributes:
        user_id (Union[Unset, str]):
        mini_id (Union[Unset, int]):
        mini_name (Union[Unset, str]):
        mini_description (Union[None, Unset, str]):
    """

    user_id: Union[Unset, str] = UNSET
    mini_id: Union[Unset, int] = UNSET
    mini_name: Union[Unset, str] = UNSET
    mini_description: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        user_id = self.user_id

        mini_id = self.mini_id

        mini_name = self.mini_name

        mini_description: Union[None, Unset, str]
        if isinstance(self.mini_description, Unset):
            mini_description = UNSET
        else:
            mini_description = self.mini_description

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if user_id is not UNSET:
            field_dict["userId"] = user_id
        if mini_id is not UNSET:
            field_dict["miniId"] = mini_id
        if mini_name is not UNSET:
            field_dict["miniName"] = mini_name
        if mini_description is not UNSET:
            field_dict["miniDescription"] = mini_description

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        user_id = d.pop("userId", UNSET)

        mini_id = d.pop("miniId", UNSET)

        mini_name = d.pop("miniName", UNSET)

        def _parse_mini_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        mini_description = _parse_mini_description(d.pop("miniDescription", UNSET))

        user_to_mini_dto = cls(
            user_id=user_id,
            mini_id=mini_id,
            mini_name=mini_name,
            mini_description=mini_description,
        )

        return user_to_mini_dto



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ToolDto")


@_attrs_define
class ToolDto:
    """
    Attributes:
        id (Union[Unset, int]):
        name (Union[Unset, str]):
        description (Union[Unset, str]):
        endpoint (Union[Unset, str]):
        schema (Union[Unset, str]):
    """

    id: Union[Unset, int] = UNSET
    name: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    endpoint: Union[Unset, str] = UNSET
    schema: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        name = self.name

        description = self.description

        endpoint = self.endpoint

        schema = self.schema

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if endpoint is not UNSET:
            field_dict["endpoint"] = endpoint
        if schema is not UNSET:
            field_dict["schema"] = schema

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        endpoint = d.pop("endpoint", UNSET)

        schema = d.pop("schema", UNSET)

        tool_dto = cls(
            id=id,
            name=name,
            description=description,
            endpoint=endpoint,
            schema=schema,
        )

        return tool_dto



from typing import Literal, cast

FormFieldType = Literal["checkbox", "dateTime", "radio", "text"]

FORM_FIELD_TYPE_VALUES: set[FormFieldType] = {
    "checkbox",
    "dateTime",
    "radio",
    "text",
}


def check_form_field_type(value: str) -> FormFieldType:
    if value in FORM_FIELD_TYPE_VALUES:
        return cast(FormFieldType, value)
    raise TypeError(f"Unexpected value {value!r}. Expected one of {FORM_FIELD_TYPE_VALUES!r}")



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="RecordAuthorization")


@_attrs_define
class RecordAuthorization:
    """
    Attributes:
        users (Union[Unset, list[str]]):
        minis (Union[Unset, list[str]]):
        organizations (Union[Unset, list[str]]):
        sessions (Union[Unset, list[str]]):
    """

    users: Union[Unset, list[str]] = UNSET
    minis: Union[Unset, list[str]] = UNSET
    organizations: Union[Unset, list[str]] = UNSET
    sessions: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        users: Union[Unset, list[str]] = UNSET
        if not isinstance(self.users, Unset):
            users = self.users

        minis: Union[Unset, list[str]] = UNSET
        if not isinstance(self.minis, Unset):
            minis = self.minis

        organizations: Union[Unset, list[str]] = UNSET
        if not isinstance(self.organizations, Unset):
            organizations = self.organizations

        sessions: Union[Unset, list[str]] = UNSET
        if not isinstance(self.sessions, Unset):
            sessions = self.sessions

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if users is not UNSET:
            field_dict["users"] = users
        if minis is not UNSET:
            field_dict["minis"] = minis
        if organizations is not UNSET:
            field_dict["organizations"] = organizations
        if sessions is not UNSET:
            field_dict["sessions"] = sessions

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        users = cast(list[str], d.pop("users", UNSET))

        minis = cast(list[str], d.pop("minis", UNSET))

        organizations = cast(list[str], d.pop("organizations", UNSET))

        sessions = cast(list[str], d.pop("sessions", UNSET))

        record_authorization = cls(
            users=users,
            minis=minis,
            organizations=organizations,
            sessions=sessions,
        )

        return record_authorization



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.record_attachment_metadata_type_0 import RecordAttachmentMetadataType0


T = TypeVar("T", bound="RecordAttachment")


@_attrs_define
class RecordAttachment:
    """
    Attributes:
        id (Union[Unset, str]):
        file_name (Union[Unset, str]):
        content_type (Union[Unset, str]):
        size (Union[Unset, int]):
        checksum (Union[None, Unset, str]):
        uri (Union[Unset, str]):
        created_at (Union[None, Unset, datetime.datetime]):
        updated_at (Union[None, Unset, datetime.datetime]):
        created_by (Union[None, Unset, str]):
        updated_by (Union[None, Unset, str]):
        metadata (Union['RecordAttachmentMetadataType0', None, Unset]):
    """

    id: Union[Unset, str] = UNSET
    file_name: Union[Unset, str] = UNSET
    content_type: Union[Unset, str] = UNSET
    size: Union[Unset, int] = UNSET
    checksum: Union[None, Unset, str] = UNSET
    uri: Union[Unset, str] = UNSET
    created_at: Union[None, Unset, datetime.datetime] = UNSET
    updated_at: Union[None, Unset, datetime.datetime] = UNSET
    created_by: Union[None, Unset, str] = UNSET
    updated_by: Union[None, Unset, str] = UNSET
    metadata: Union["RecordAttachmentMetadataType0", None, Unset] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.record_attachment_metadata_type_0 import RecordAttachmentMetadataType0

        id = self.id

        file_name = self.file_name

        content_type = self.content_type

        size = self.size

        checksum: Union[None, Unset, str]
        if isinstance(self.checksum, Unset):
            checksum = UNSET
        else:
            checksum = self.checksum

        uri = self.uri

        created_at: Union[None, Unset, str]
        if isinstance(self.created_at, Unset):
            created_at = UNSET
        elif isinstance(self.created_at, datetime.datetime):
            created_at = self.created_at.isoformat()
        else:
            created_at = self.created_at

        updated_at: Union[None, Unset, str]
        if isinstance(self.updated_at, Unset):
            updated_at = UNSET
        elif isinstance(self.updated_at, datetime.datetime):
            updated_at = self.updated_at.isoformat()
        else:
            updated_at = self.updated_at

        created_by: Union[None, Unset, str]
        if isinstance(self.created_by, Unset):
            created_by = UNSET
        else:
            created_by = self.created_by

        updated_by: Union[None, Unset, str]
        if isinstance(self.updated_by, Unset):
            updated_by = UNSET
        else:
            updated_by = self.updated_by

        metadata: Union[None, Unset, dict[str, Any]]
        if isinstance(self.metadata, Unset):
            metadata = UNSET
        elif isinstance(self.metadata, RecordAttachmentMetadataType0):
            metadata = self.metadata.to_dict()
        else:
            metadata = self.metadata

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if file_name is not UNSET:
            field_dict["fileName"] = file_name
        if content_type is not UNSET:
            field_dict["contentType"] = content_type
        if size is not UNSET:
            field_dict["size"] = size
        if checksum is not UNSET:
            field_dict["checksum"] = checksum
        if uri is not UNSET:
            field_dict["uri"] = uri
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if updated_by is not UNSET:
            field_dict["updatedBy"] = updated_by
        if metadata is not UNSET:
            field_dict["metadata"] = metadata

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.record_attachment_metadata_type_0 import RecordAttachmentMetadataType0

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        file_name = d.pop("fileName", UNSET)

        content_type = d.pop("contentType", UNSET)

        size = d.pop("size", UNSET)

        def _parse_checksum(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        checksum = _parse_checksum(d.pop("checksum", UNSET))

        uri = d.pop("uri", UNSET)

        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                created_at_type_0 = isoparse(data)

                return created_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        created_at = _parse_created_at(d.pop("createdAt", UNSET))

        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                updated_at_type_0 = isoparse(data)

                return updated_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        updated_at = _parse_updated_at(d.pop("updatedAt", UNSET))

        def _parse_created_by(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        created_by = _parse_created_by(d.pop("createdBy", UNSET))

        def _parse_updated_by(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        updated_by = _parse_updated_by(d.pop("updatedBy", UNSET))

        def _parse_metadata(data: object) -> Union["RecordAttachmentMetadataType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                metadata_type_0 = RecordAttachmentMetadataType0.from_dict(data)

                return metadata_type_0
            except:  # noqa: E722
                pass
            return cast(Union["RecordAttachmentMetadataType0", None, Unset], data)

        metadata = _parse_metadata(d.pop("metadata", UNSET))

        record_attachment = cls(
            id=id,
            file_name=file_name,
            content_type=content_type,
            size=size,
            checksum=checksum,
            uri=uri,
            created_at=created_at,
            updated_at=updated_at,
            created_by=created_by,
            updated_by=updated_by,
            metadata=metadata,
        )

        return record_attachment



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkspaceDto")


@_attrs_define
class WorkspaceDto:
    """
    Attributes:
        id (Union[Unset, int]):
        workspace_id (Union[Unset, str]):
        name (Union[Unset, str]):
        organization_id (Union[None, Unset, str]):
    """

    id: Union[Unset, int] = UNSET
    workspace_id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    organization_id: Union[None, Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        workspace_id = self.workspace_id

        name = self.name

        organization_id: Union[None, Unset, str]
        if isinstance(self.organization_id, Unset):
            organization_id = UNSET
        else:
            organization_id = self.organization_id

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if workspace_id is not UNSET:
            field_dict["workspaceId"] = workspace_id
        if name is not UNSET:
            field_dict["name"] = name
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        workspace_id = d.pop("workspaceId", UNSET)

        name = d.pop("name", UNSET)

        def _parse_organization_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        organization_id = _parse_organization_id(d.pop("organizationId", UNSET))

        workspace_dto = cls(
            id=id,
            workspace_id=workspace_id,
            name=name,
            organization_id=organization_id,
        )

        return workspace_dto
